@@ -104,6 +104,11 @@ class NamedMatrix(object):
         Override the [] method.
         """
         rows,cols = key
+        if type(rows) is str:
+            rows = [rows]
+        if type(cols) is str:
+            cols = [cols]
+        
         if type(cols) is list or type(rows) is list:
             return self._getitem_list(rows, cols)
         
@@ -143,6 +148,9 @@ class NamedMatrix(object):
         elif type(cols) is list:
             rows = filter(lambda x: not x is None, [i if type(i) is int else self.row_index(i) for i in rows])
         
+        if len(cols) == 1 and len(rows) == 1:
+            return self._data[cols[0],rows[0]]
+        
         new_data = [[self._data[i,j] for j in cols] for i in rows]
         new_rownames = [self.rownames[i] for i in rows]
         new_colnames = [self.colnames[i] for i in cols]
@@ -279,7 +287,7 @@ class NamedMatrix(object):
         """
         Return a matrix with only the columns and rows that are given.
         """
-        print >> sys.stderr, "The filter method has been deprecated. You can now directly" + \
+        print >> sys.stderr, "The filter method has been deprecated. You can now directly " + \
             "index the NamedMatrix using row and column names. (eg. A[:,[colname1, colname2, ...]])"
         return self[rows,columns]
     
